@@ -39,6 +39,10 @@ Ausearch::Ausearch(QWidget *parent, const char *name): QDialog(parent, name)
 	setCaption(tr("Ausearch"));
 
 	ausearchLabel = new QLabel(tr("Search about"),this);
+	startdayLabel = new QLabel(tr("start-day(1/1/2008)"),this);
+	starttimeLabel = new QLabel(tr("start-time"),this);
+	enddayLabel = new QLabel(tr("end-day"),this);
+	endtimeLabel = new QLabel(tr("end-time"),this);
         optionButtonGroup = new QButtonGroup(this);
         optionButtonGroup->resize( 650, 350 );
         eventRadioButton = new QRadioButton(tr("events (audit-event-id)"), optionButtonGroup);
@@ -78,6 +82,22 @@ Ausearch::Ausearch(QWidget *parent, const char *name): QDialog(parent, name)
         ausearchEditLineEdit->setText("");
         ausearchEditLineEdit->setPaletteBackgroundColor(QColor(200,200,140));
 
+	startdayEditLineEdit = new QLineEdit( this );
+        startdayEditLineEdit->setText("this-year");
+        startdayEditLineEdit->setPaletteBackgroundColor(QColor(200,200,140));
+
+	starttimeEditLineEdit = new QLineEdit( this );
+        starttimeEditLineEdit->setText("04:00:00");
+        starttimeEditLineEdit->setPaletteBackgroundColor(QColor(200,200,140));
+
+	enddayEditLineEdit = new QLineEdit( this );
+        enddayEditLineEdit->setText("today");
+        enddayEditLineEdit->setPaletteBackgroundColor(QColor(200,200,140));
+
+	endtimeEditLineEdit = new QLineEdit( this );
+        endtimeEditLineEdit->setText("");
+        endtimeEditLineEdit->setPaletteBackgroundColor(QColor(200,200,140));
+
 	ausearchButton = new QPushButton(tr("Search"), this);
 	ausearchButton->setPaletteBackgroundColor(QColor(250,180,200));
 	connect(ausearchButton, SIGNAL(clicked()), this, SLOT(ausearch_button_clicked()));
@@ -93,21 +113,44 @@ Ausearch::Ausearch(QWidget *parent, const char *name): QDialog(parent, name)
 	//second_horizontal_Layout = new QHBoxLayout;
 	secondLayout = new QVBoxLayout;
 	thirdLayout = new QVBoxLayout;
+	tirsharyLayout = new QHBoxLayout;
+	quadroLayout = new QHBoxLayout;
 	fourthLayout = new QHBoxLayout;
 	footLayout = new QHBoxLayout;
 	
 	mainLayout->setMargin(11);
+
 	secondLayout->addWidget(ausearchLabel);
 	secondLayout->addWidget(optionButtonGroup);
+
 	thirdLayout->addStretch();
 	thirdLayout->addWidget(ausearchEditLineEdit);
+	thirdLayout->addStretch();
+
+	tirsharyLayout->addStretch();
+	tirsharyLayout->addWidget(startdayLabel);
+	tirsharyLayout->addWidget(startdayEditLineEdit);
+	tirsharyLayout->addWidget(starttimeLabel);
+	tirsharyLayout->addWidget(starttimeEditLineEdit);
+	tirsharyLayout->addStretch();
+
+	quadroLayout->addStretch();
+	quadroLayout->addWidget(enddayLabel);
+	quadroLayout->addWidget(enddayEditLineEdit);
+	quadroLayout->addWidget(endtimeLabel);
+	quadroLayout->addWidget(endtimeEditLineEdit);
+	quadroLayout->addStretch();
+
 	thirdLayout->addStretch();
 	thirdLayout->addWidget(interpretCheckBox);
+	thirdLayout->addLayout(tirsharyLayout);
+	thirdLayout->addLayout(quadroLayout);
 
 	fourthLayout->addStretch();
 	fourthLayout->addWidget(ausearchButton);
 	fourthLayout->addStretch();
 
+
 	firstLayout->addLayout(secondLayout);
 	firstLayout->addLayout(thirdLayout);
 
@@ -189,6 +232,18 @@ void Ausearch::ausearch_button_clicked()
         if(interpretCheckBox->isChecked()){
                 ausearch_str_pp_str = ausearch_str_pp_str + " -i";
 	}
+	//set start-day and start-time
+	startdayEditLineEdit_str = startdayEditLineEdit->text();
+	starttimeEditLineEdit_str = starttimeEditLineEdit->text();
+        if(startdayEditLineEdit_str != ""){
+		ausearch_str_pp_str = ausearch_str_pp_str + " --start " + startdayEditLineEdit_str + " " + starttimeEditLineEdit_str;
+	}
+	//set end-day and end-time
+	enddayEditLineEdit_str = enddayEditLineEdit->text();
+	endtimeEditLineEdit_str = endtimeEditLineEdit->text();
+        if(enddayEditLineEdit_str != ""){
+		ausearch_str_pp_str = ausearch_str_pp_str + " --end " + enddayEditLineEdit_str + " " + endtimeEditLineEdit_str;
+	}
 
 	ausearch_process = new AusearchProcess(this);
 	//connect(ausearch_process, SIGNAL(ausearch_process_close_button_clicked()), this, SLOT(close()));
