@@ -67,6 +67,7 @@
 #include "seeprocess.h"
 #include "restorecon.h"
 #include "mainwindow.h"
+#include "downloader.h"
 
 MainWindow::MainWindow(QWidget *parent, const char *name)
 	: QMainWindow(parent, name)
@@ -112,6 +113,7 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	useradd_o = 0;
 	seeprocess_o = 0;
 	restorecon_o = 0;
+	downloader_o = 0;
 
 	//connect SIGNAL to objects    
 
@@ -127,7 +129,7 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	createToolBars();
 	createStatusBar();
 
-	setCaption(tr("segatex-6.20"));
+	setCaption(tr("segatex-6.30"));
 	setIcon(QPixmap::fromMimeSource("icon.png"));
 }
 
@@ -491,6 +493,11 @@ void MainWindow::createActions()
 	restoreconAct->setStatusTip(tr("restorecon"));
 	connect(restoreconAct, SIGNAL(activated()), this, SLOT(restorecon()));
 	connect(restoreconAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	downloaderAct = new QAction(tr("&download Fedora"), 0, this);
+	downloaderAct->setStatusTip(tr("download Fedora"));
+	connect(downloaderAct, SIGNAL(activated()), this, SLOT(downloader()));
+	connect(downloaderAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 }
 
 void MainWindow::createMenus()
@@ -575,9 +582,12 @@ void MainWindow::createMenus()
 	semanage_core_translation_processAct->addTo(semanageMenu);
 	semanage_core_boolean_processAct->addTo(semanageMenu);
 
-	autorelabelMenu = new QPopupMenu(this);
-	restoreconAct->addTo(autorelabelMenu);
-	autorelabel_processAct->addTo(autorelabelMenu);
+	relabelMenu = new QPopupMenu(this);
+	restoreconAct->addTo(relabelMenu);
+	autorelabel_processAct->addTo(relabelMenu);
+
+	downloaderMenu = new QPopupMenu(this);
+	downloaderAct->addTo(downloaderMenu);
 
 	miscellaneousMenu = new QPopupMenu(this);
 	useraddAct->addTo(miscellaneousMenu);
@@ -600,7 +610,10 @@ void MainWindow::createMenus()
 	menuBar()->insertItem(tr("&Refine"), refineMenu);
 
 	menuBar()->insertSeparator();
-	menuBar()->insertItem(tr("Re&label"), autorelabelMenu);
+	menuBar()->insertItem(tr("Re&label"), relabelMenu);
+
+	menuBar()->insertSeparator();
+	menuBar()->insertItem(tr("&Download"), downloaderMenu);
 
 	menuBar()->insertSeparator();
 	menuBar()->insertItem(tr("Mis&c"), miscellaneousMenu);
@@ -940,7 +953,7 @@ void MainWindow::notice()
 void MainWindow::about()
 {
 	QMessageBox::about(this, tr("About segatex"),
-		tr("<h2>segatex-6.20</h2>"
+		tr("<h2>segatex-6.30</h2>"
 		"<p>Copyright &copy; 2007-2008"
 		"<p>Shintaro Fujiwara."
 		"<p>segatex is a SELinux tool"
@@ -967,6 +980,8 @@ void MainWindow::howtouse()
 		" You can aureport."
 		" You can ausearch."
 		" You can restorecon."
+		" You can add/delete Linux user."
+		" You can ftp download."
 		"<p><font color=\"blue\">[segatex_editor]</font>"
 		"<p>Push Parselines,Selpaw,Refine"
 		" one by one orderly."
@@ -1247,3 +1262,12 @@ void MainWindow::restorecon()
 	restorecon_o->raise();
 	restorecon_o->setActiveWindow();
 }
+void MainWindow::downloader()
+{
+	if(!downloader_o) {
+		downloader_o = new Downloader(this);
+	}
+	downloader_o->show();
+	downloader_o->raise();
+	downloader_o->setActiveWindow();
+}
