@@ -103,19 +103,19 @@
     </message>
     <message>
         <source>start-day(1/1/2008)</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">開始日(2008年01月01日)</translation>
     </message>
     <message>
         <source>start-time</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">開始時間</translation>
     </message>
     <message>
         <source>end-day</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">終了日</translation>
     </message>
     <message>
         <source>end-time</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">終了時間</translation>
     </message>
 </context>
 <context>
@@ -239,7 +239,7 @@
     <name>AutoRelabel</name>
     <message>
         <source>Autorelabel Process</source>
-        <translation type="unfinished">再ラベル付過程</translation>
+        <translation type="unfinished">全システムの再ラベル付過程</translation>
     </message>
     <message>
         <source>now</source>
@@ -251,7 +251,7 @@
     </message>
     <message>
         <source>Autorelabel</source>
-        <translation type="unfinished">再ラベル付け</translation>
+        <translation type="unfinished">全システムの再ラベル付け</translation>
     </message>
     <message>
         <source>close</source>
@@ -798,11 +798,11 @@ Do you want to save your changes?</source>
     </message>
     <message>
         <source>auto&amp;relabel </source>
-        <translation type="unfinished">再ラベル付け</translation>
+        <translation type="unfinished">全システムの再ラベル付け</translation>
     </message>
     <message>
         <source>autorelabel the system.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">システム全体を再ラベル付け</translation>
     </message>
     <message>
         <source>Policy_&amp;module </source>
@@ -902,7 +902,7 @@ Do you want to save your changes?</source>
     </message>
     <message>
         <source>&lt;h2&gt;How to use segatex&lt;/h2&gt;&lt;p&gt;&lt;font color=&quot;blue&quot;&gt;[segatex]&lt;/font&gt;&lt;p&gt;You can set selinux enforcing and permissive just pushing button. You can install/update SELinux related RPMs.You can audit2allow You can analize audit log. You can manage modules. You can semanage. You can setsebool. You can relabel the system. You can generate brand-new policy module. You can generate interfaced policy,by  Analize audit.log-generate policy. You can aureport. You can ausearch.&lt;p&gt;&lt;font color=&quot;blue&quot;&gt;[segatex_editor]&lt;/font&gt;&lt;p&gt;Push Parselines,Selpaw,Refine one by one orderly.&lt;p&gt;If you could get three selpaw files,i.e.selpaw_interface.csv,selpaw_interface_types.csv,selpaw_interface_summary.csv, that is a success.&lt;p&gt;Break kernel may take 30 minutes, and Refine selpaw takes 10 minutes;)&lt;/p&gt;</source>
-        <translation type="unfinished">&lt;h2&gt;segatexの使用法&lt;/h2&gt;&lt;p&gt;&lt;font color=&quot;blue&quot;&gt;[segatex]&lt;/font&gt;&lt;p&gt;ボタンを押すだけでSELinuxのモードを切り替えられます。SELinux関連のパッケージをインストール/アップデート出来ます。ログからポリシを生成できます。モジュールを操作できます。SELinuxの設定ができます。ブーリアンを切り替えられます。システムのラベルを付け直せます。独自ポリシもジュールを生成できます。Refpolicyの形式でポリシを生成できます。ログを検索したり、レポートを生成したりできます。&lt;p&gt;&lt;font color=&quot;blue&quot;&gt;[segatex_editor]&lt;/font&gt;&lt;p&gt;分解準備-分解ボタンを順番に押して行って下さい。&lt;p&gt; ３つのselpaw files、すなわち、selpaw_interface.csv,selpaw_interface_types.csv,selpaw_interface_summary.csvが生成されれば成功です。&lt;p&gt;カーネルレイヤーファイルの分解には30分はかかります。Refine selpaw takes 10 minutes;)&lt;/p&gt;</translation>
+        <translation type="obsolete">&lt;h2&gt;segatexの使用法&lt;/h2&gt;&lt;p&gt;&lt;font color=&quot;blue&quot;&gt;[segatex]&lt;/font&gt;&lt;p&gt;ボタンを押すだけでSELinuxのモードを切り替えられます。SELinux関連のパッケージをインストール/アップデート出来ます。ログからポリシを生成できます。モジュールを操作できます。SELinuxの設定ができます。ブーリアンを切り替えられます。システムのラベルを付け直せます。独自ポリシもジュールを生成できます。Refpolicyの形式でポリシを生成できます。ログを検索したり、レポートを生成したりできます。&lt;p&gt;&lt;font color=&quot;blue&quot;&gt;[segatex_editor]&lt;/font&gt;&lt;p&gt;分解準備-分解ボタンを順番に押して行って下さい。&lt;p&gt; ３つのselpaw files、すなわち、selpaw_interface.csv,selpaw_interface_types.csv,selpaw_interface_summary.csvが生成されれば成功です。&lt;p&gt;カーネルレイヤーファイルの分解には30分はかかります。Refine selpaw takes 10 minutes;)&lt;/p&gt;</translation>
     </message>
     <message>
         <source>%1 %2</source>
@@ -970,11 +970,11 @@ Do you want to save your changes?</source>
     </message>
     <message>
         <source>segatex-6.00</source>
-        <translation type="unfinished">segatexバージョン6.00</translation>
+        <translation type="obsolete">segatexバージョン6.00</translation>
     </message>
     <message>
         <source>&lt;h2&gt;segatex-6.00&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatex is a SELinux tool&lt;p&gt;&lt;b&gt;written with Qt&lt;/b&gt;.</source>
-        <translation type="unfinished">&lt;h2&gt;segatex-6.00&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatexはSELinuxのツールです。&lt;p&gt;&lt;b&gt;Qtを使用して書かれています。&lt;/b&gt;.</translation>
+        <translation type="obsolete">&lt;h2&gt;segatex-6.00&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatexはSELinuxのツールです。&lt;p&gt;&lt;b&gt;Qtを使用して書かれています。&lt;/b&gt;.</translation>
     </message>
     <message>
         <source>&amp;Useradd/delete</source>
@@ -992,6 +992,26 @@ Do you want to save your changes?</source>
         <source>see process</source>
         <translation type="unfinished">プロセスを見る</translation>
     </message>
+    <message>
+        <source>segatex-6.20</source>
+        <translation type="unfinished">segatexバージョン6.20</translation>
+    </message>
+    <message>
+        <source>&amp;restorecon</source>
+        <translation type="unfinished">パスを指定して再ラベル付け</translation>
+    </message>
+    <message>
+        <source>restorecon</source>
+        <translation type="unfinished">パスを指定して再ラベル付け</translation>
+    </message>
+    <message>
+        <source>&lt;h2&gt;segatex-6.20&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatex is a SELinux tool&lt;p&gt;&lt;b&gt;written with Qt&lt;/b&gt;.</source>
+        <translation type="unfinished">&lt;h2&gt;segatex-6.20&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatexはSELinuxのツールです。&lt;p&gt;&lt;b&gt;Qtを使用して書かれています。&lt;/b&gt;.</translation>
+    </message>
+    <message>
+        <source>&lt;h2&gt;How to use segatex&lt;/h2&gt;&lt;p&gt;&lt;font color=&quot;blue&quot;&gt;[segatex]&lt;/font&gt;&lt;p&gt;You can set selinux enforcing and permissive just pushing button. You can install/update SELinux related RPMs.You can audit2allow You can analize audit log. You can manage modules. You can semanage. You can setsebool. You can relabel the system. You can generate brand-new policy module. You can generate interfaced policy,by  Analize audit.log-generate policy. You can aureport. You can ausearch. You can restorecon.&lt;p&gt;&lt;font color=&quot;blue&quot;&gt;[segatex_editor]&lt;/font&gt;&lt;p&gt;Push Parselines,Selpaw,Refine one by one orderly.&lt;p&gt;If you could get three selpaw files,i.e.selpaw_interface.csv,selpaw_interface_types.csv,selpaw_interface_summary.csv, that is a success.&lt;p&gt;Break kernel may take 30 minutes, and Refine selpaw takes 10 minutes;)&lt;/p&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Policygeneration</name>
@@ -1058,6 +1078,37 @@ Do you want to save your changes?</source>
         <translation type="unfinished">メインウインドウをセッティングする</translation>
     </message>
 </context>
+<context>
+    <name>Restorecon</name>
+    <message>
+        <source>Restorecon</source>
+        <translation type="unfinished">パスを指定して再ラベル付け</translation>
+    </message>
+    <message>
+        <source>close</source>
+        <translation type="unfinished">閉じる</translation>
+    </message>
+    <message>
+        <source>restorecon -R -v </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>segatex alert</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No path given.
+Try again !</source>
+        <translation type="unfinished">パスが指定されていません。もう一度！</translation>
+    </message>
+</context>
+<context>
+    <name>RestoreconProcess</name>
+    <message>
+        <source>close</source>
+        <translation type="unfinished">閉じる</translation>
+    </message>
+</context>
 <context>
     <name>Seeprocess</name>
     <message>
